==> mteb-1.38.47.tar.gz: mteb-1.38.47/mteb/benchmarks/benchmarks/__init__.py <==
from __future__ import annotations

from mteb.benchmarks.benchmark import Benchmark
from mteb.benchmarks.benchmarks.benchmarks import (
    MTEB_EN,
    MTEB_ENG_CLASSIC,
    MTEB_MAIN_RU,
    RU_SCI_BENCH,
    MTEB_RETRIEVAL_WITH_INSTRUCTIONS,
    MTEB_RETRIEVAL_LAW,
    MTEB_RETRIEVAL_MEDICAL,
    MTEB_MINERS_BITEXT_MINING,
    SEB,
    CoIR,
    RAR_b,
    MTEB_FRA,
    MTEB_DEU,
    MTEB_KOR,
    MTEB_POL,
    MTEB_code,
    MTEB_multilingual,
    MTEB_multilingual,
    MTEB_JPN,
    MTEB_INDIC,
    MTEB_EU,
    LONG_EMBED,
    BRIGHT,
    BRIGHT_LONG,
    CODE_RAG,
    BEIR,
    NANOBEIR,
    C_MTEB,
    FA_MTEB,
    CHEMTEB,
    BEIR_NL,
    MIEB_ENG,
    MIEB_MULTILINGUAL,
    MIEB_LITE,
    MIEB_IMG,
    BUILT_MTEB,
    ENCODECHKA,
    VIDORE,
    VIDORE_V2,
    VISUAL_DOCUMENT_RETRIEVAL,
    R2MED,
    VN_MTEB,
    JINA_VDR,
)

__all__ = [
    "Benchmark",
    "MTEB_EN",
    "MTEB_ENG_CLASSIC",
    "MTEB_MAIN_RU",
    "RU_SCI_BENCH",
    "MTEB_RETRIEVAL_WITH_INSTRUCTIONS",
    "MTEB_RETRIEVAL_LAW",
    "MTEB_RETRIEVAL_MEDICAL",
    "MTEB_MINERS_BITEXT_MINING",
    "SEB",
    "CoIR",
    "RAR_b",
    "MTEB_FRA",
    "MTEB_DEU",
    "MTEB_KOR",
    "MTEB_POL",
    "MTEB_code",
    "MTEB_multilingual",
    "MTEB_JPN",
    "MTEB_INDIC",
    "MTEB_EU",
    "LONG_EMBED",
    "BRIGHT",
    "BRIGHT_LONG",
    "CODE_RAG",
    "BEIR",
    "NANOBEIR",
    "C_MTEB",
    "FA_MTEB",
    "CHEMTEB",
    "BEIR_NL",
    "MIEB_ENG",
    "MIEB_MULTILINGUAL",
    "MIEB_LITE",
    "MIEB_IMG",
    "BUILT_MTEB",
    "ENCODECHKA",
    "VIDORE",
    "VIDORE_V2",
    "VISUAL_DOCUMENT_RETRIEVAL",
    "R2MED",
    "VN_MTEB",
    "JINA_VDR",
]

==> mteb-1.38.57.tar.gz: mteb-1.38.57/mteb/benchmarks/benchmarks/__init__.py <==
from __future__ import annotations

from mteb.benchmarks.benchmark import Benchmark
from mteb.benchmarks.benchmarks.benchmarks import (
    BEIR,
    BEIR_NL,
    BRIGHT,
    BRIGHT_LONG,
    BUILT_MTEB,
    C_MTEB,
    CHEMTEB,
    CODE_RAG,
    ENCODECHKA,
    FA_MTEB,
    FA_MTEB_2,
    JINA_VDR,
    LONG_EMBED,
    MIEB_ENG,
    MIEB_IMG,
    MIEB_LITE,
    MIEB_MULTILINGUAL,
    MTEB_DEU,
    MTEB_EN,
    MTEB_ENG_CLASSIC,
    MTEB_EU,
    MTEB_FRA,
    MTEB_INDIC,
    MTEB_JPN,
    MTEB_KOR,
    MTEB_MAIN_RU,
    MTEB_MINERS_BITEXT_MINING,
    MTEB_POL,
    MTEB_RETRIEVAL_LAW,
    MTEB_RETRIEVAL_MEDICAL,
    MTEB_RETRIEVAL_WITH_INSTRUCTIONS,
    NANOBEIR,
    R2MED,
    RU_SCI_BENCH,
    SEB,
    VIDORE,
    VIDORE_V2,
    VISUAL_DOCUMENT_RETRIEVAL,
    VN_MTEB,
    CoIR,
    MTEB_code,
    MTEB_multilingual_v1,
    MTEB_multilingual_v2,
    RAR_b,
)
from mteb.benchmarks.benchmarks.rteb_benchmarks import (
    RTEB_CODE,
    RTEB_ENGLISH,
    RTEB_FINANCE,
    RTEB_FRENCH,
    RTEB_GERMAN,
    RTEB_HEALTHCARE,
    RTEB_LEGAL,
    RTEB_MAIN,
)

__all__ = [
    "Benchmark",
    "MTEB_EN",
    "MTEB_ENG_CLASSIC",
    "MTEB_MAIN_RU",
    "RU_SCI_BENCH",
    "MTEB_RETRIEVAL_WITH_INSTRUCTIONS",
    "MTEB_RETRIEVAL_LAW",
    "MTEB_RETRIEVAL_MEDICAL",
    "MTEB_MINERS_BITEXT_MINING",
    "SEB",
    "CoIR",
    "RAR_b",
    "MTEB_FRA",
    "MTEB_DEU",
    "MTEB_KOR",
    "MTEB_POL",
    "MTEB_code",
    "MTEB_multilingual_v1",
    "MTEB_multilingual_v2",
    "MTEB_JPN",
    "MTEB_INDIC",
    "MTEB_EU",
    "LONG_EMBED",
    "BRIGHT",
    "BRIGHT_LONG",
    "CODE_RAG",
    "BEIR",
    "NANOBEIR",
    "C_MTEB",
    "FA_MTEB",
    "FA_MTEB_2",
    "CHEMTEB",
    "BEIR_NL",
    "MIEB_ENG",
    "MIEB_MULTILINGUAL",
    "MIEB_LITE",
    "MIEB_IMG",
    "BUILT_MTEB",
    "ENCODECHKA",
    "VIDORE",
    "VIDORE_V2",
    "VISUAL_DOCUMENT_RETRIEVAL",
    "R2MED",
    "VN_MTEB",
    "JINA_VDR",
    "RTEB_MAIN",
    "RTEB_FINANCE",
    "RTEB_LEGAL",
    "RTEB_CODE",
    "RTEB_HEALTHCARE",
    "RTEB_ENGLISH",
    "RTEB_FRENCH",
    "RTEB_GERMAN",
]
